@@ -18,13 +18,14 @@ import transformers
 
 from proquo.model.reference.ReferenceVectorizer import ReferenceVectorizer
 from proquo.testing.reference import TestReference
-from proquo.testing.relation import TestRelationBert, TestRelationLstm
+from proquo.testing.relation import TestRelationBert
 from proquo.training.reference import TrainReference
 from proquo.training.relation import TrainRelationBert
 
 # only import if tensorflow_text is found. This is hardly ever needed and tensorflow_text is not always easy to install.
 try:
     from proquo.training.relation import TrainRelationLstm
+    from proquo.testing.relation import TestRelationLstm
 except ModuleNotFoundError:
     pass
 
