@@ -1,4 +1,4 @@
-from proquo.model import RelationModelLstm
+from proquo.model.relation.RelationModelLstm import RelationModelLstm
 
 
 def train(train_file_path, val_file_path, output_folder_path):
